@@ -1,7 +1,7 @@
 package App::fatten;
 
-our $DATE = '2014-11-09'; # DATE
-our $VERSION = '0.11'; # VERSION
+our $DATE = '2014-11-10'; # DATE
+our $VERSION = '0.12'; # VERSION
 
 use 5.010001;
 use strict;
@@ -118,9 +118,15 @@ sub _build_lib {
         }
 
         if ($self->{strip}) {
-            state $stripper = do {
+            my $stripper = do {
                 require Perl::Stripper;
-                Perl::Stripper->new;
+                Perl::Stripper->new(
+                    maintain_linum => 0,
+                    strip_ws       => $self->{strip_ws},
+                    strip_comment  => $self->{strip_comment},
+                    strip_pod      => $self->{strip_pod},
+                    strip_log      => $self->{strip_log},
+                );
             };
             $log->debug("  Stripping $mpath --> $modp ...");
             my $src = read_file($mpath);
@@ -289,12 +295,39 @@ Will be passed to the tracer. Will currently only affect the `fatpacker` and
 
 _
         },
+
         strip => {
             summary => 'Whether to strip included modules using Perl::Stripper',
             schema => ['bool' => default=>0],
             cmdline_aliases => { s=>{} },
         },
-        # XXX strip_opts
+        strip_maintain_linum => {
+            summary => "Will be passed to Perl::Stripper's maintain_linum",
+            schema => ['bool'],
+            default => 0,
+        },
+        strip_ws => {
+            summary => "Will be passed to Perl::Stripper's strip_ws",
+            schema => ['bool'],
+            default => 1,
+        },
+        strip_comment => {
+            summary => "Will be passed to Perl::Stripper's strip_comment",
+            schema => ['bool'],
+            default => 1,
+        },
+        strip_pod => {
+            summary => "Will be passed to Perl::Stripper's strip_pod",
+            schema => ['bool'],
+            default => 1,
+        },
+        strip_log => {
+            summary => "Will be passed to Perl::Stripper's strip_log",
+            schema => ['bool'],
+            default => 0,
+        },
+        # XXX strip_log_levels
+
         debug_keep_tempdir => {
             summary => 'Keep temporary directory for debugging',
             schema => ['bool' => default=>0],
@@ -417,7 +450,7 @@ App::fatten - Pack your dependencies onto your script file
 
 =head1 VERSION
 
-This document describes version 0.11 of App::fatten (from Perl distribution App-fatten), released on 2014-11-09.
+This document describes version 0.12 of App::fatten (from Perl distribution App-fatten), released on 2014-11-10.
 
 =head1 SYNOPSIS
 
@@ -509,6 +542,26 @@ different sets of core modules as well as different versions of the modules.
 
 Whether to strip included modules using Perl::Stripper.
 
+=item * B<strip_comment> => I<bool> (default: 1)
+
+Will be passed to Perl::Stripper's strip_comment.
+
+=item * B<strip_log> => I<bool> (default: 0)
+
+Will be passed to Perl::Stripper's strip_log.
+
+=item * B<strip_maintain_linum> => I<bool> (default: 0)
+
+Will be passed to Perl::Stripper's maintain_linum.
+
+=item * B<strip_pod> => I<bool> (default: 1)
+
+Will be passed to Perl::Stripper's strip_pod.
+
+=item * B<strip_ws> => I<bool> (default: 1)
+
+Will be passed to Perl::Stripper's strip_ws.
+
 =item * B<trace_method> => I<str> (default: "fatpacker")
 
 Which method to use to trace dependencies.
